package org.expeditee.auth.account;

import java.awt.Desktop;
import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

import org.expeditee.gui.FrameIO;
import org.expeditee.settings.UserSettings;

public class Contacts {

	public static String distributeContactDetails(String username) {
		StringBuilder sb = new StringBuilder();
		String nl = System.getProperty("line.separator");
		String me = UserSettings.UserName.get();
		Path profilePath = Paths.get(FrameIO.PROFILE_PATH).resolve(me);
		Path resourcesUsernamePath = Paths.get(FrameIO.PARENT_FOLDER).resolve("resources-" + username);
		if (resourcesUsernamePath.toFile().exists()) {
			sb.append("Detected the presence of the user " + username + " present in your Expeditee file system.  Contact details automatically distributed.");
			Path credentialsDirectoryToSharePath = profilePath.resolve(me + "-credentials");
			Path partnerContactsDirectory = resourcesUsernamePath.resolve("contacts");
			try {
				copyFileTree(credentialsDirectoryToSharePath, partnerContactsDirectory.resolve(me + "-credentials"));
				return sb.toString();
			} catch (IOException e) {
				sb = new StringBuilder();
			}
		}
		
		try {
			Desktop.getDesktop().open(profilePath.toFile());
			sb.append("1. We have opened your profile directory for you.  Tab to it and right click on the " + me + "-credentials directory." + nl);
		} catch (IOException e) {
			sb.append("1. Open your profile directory (" + profilePath + ") and right click on the " + me + "-credentials directory." + nl);
		}
		
		sb.append("2. Click on 'Share with Google Drive'." + nl);
		sb.append("3. Enter " + username + "'s in the text box." + nl);
		sb.append("4. Click on the button to the right of the text box in order to set the share to 'View Only'." + nl);
		sb.append("5. Optionally add a note for " + username + " to read.  Click the send button.");
		
		return sb.toString();
	}

	public static String addContactDetails(String username) {
		StringBuilder sb = new StringBuilder();
		String nl = System.getProperty("line.separator");
		String me = UserSettings.UserName.get();
		String driveSharedWithMeString = "https://drive.google.com/drive/shared-with-me";
		try {
			URI driveSharedWithMeURL = new URL(driveSharedWithMeString).toURI();
			Desktop.getDesktop().browse(driveSharedWithMeURL);
			sb.append("1. We have opened Google Drive to the 'Shared With Me' page in your browser.  Right click on " + username + "-credentials and click on 'Add To My Drive'." + nl);
		} catch (IOException | URISyntaxException e) {
			sb.append("1. Open your web browser to " + driveSharedWithMeString + ".  Right click on " + username + "-credentials and click on 'Add To My Drive'." + nl);
		}
		
		sb.append("2. Click organise and navigate the dialog to resources-" + me + "/contacts and click the 'Move Here' button to relocate your copy of " + username + "'s credentials folder.");
		
		return sb.toString();
	}
	
	private static void copyFileTree(Path source, Path target) throws IOException {
		if (source.toFile().isDirectory()) {
			if (!target.toFile().exists()) {
				Files.copy(source, target);
			}
			File[] files = source.toFile().listFiles();
			for (File file: files) {
				Path asPath = Paths.get(file.getAbsolutePath());
				copyFileTree(asPath, target.resolve(asPath.getFileName()));
			}
		} else {
			Files.copy(source, target);
		}
	}
}
